@@ -48,7 +48,7 @@ ge_winners <- function(.data, env, gen, resp, type = "winners", better = NULL) {
   factors  <-
     .data %>%
     select({{env}}, {{gen}}) %>%
-    mutate_all(as.factor)
+    mutate(across(everything(), as.factor))
   vars <- .data %>% select({{resp}}, -names(factors))
   vars %<>% select_numeric_cols()
   factors %<>% set_names("ENV", "GEN")
