@@ -54,7 +54,6 @@
 #' @md
 #' @references Patterson, H.D., and E.R. Williams. 1976. A new class of
 #' resolvable incomplete block designs. Biometrika 63:83-92.
-#' \href{https://doi.org/10.1093/biomet/63.1.83}{doi:10.1093/biomet/63.1.83}
 #' @seealso \code{\link{impute_missing_val}}, \code{\link{waas}}, \code{\link{waas_means}}, \code{\link{waasb}}, \code{\link{get_model_data}}
 #' @author Tiago Olivoto \email{tiagoolivoto@@gmail.com}
 #' @export
@@ -100,13 +99,13 @@ performs_ammi <- function(.data,
                    {{gen}},
                    {{rep}},
                    {{block}}) %>%
-            mutate_all(as.factor)
+            mutate(across(everything(), as.factor))
     } else{
         factors  <- .data %>%
             select({{env}},
                    {{gen}},
                    {{rep}}) %>%
-            mutate_all(as.factor)
+            mutate(across(everything(), as.factor))
     }
     vars <- .data %>% select({{resp}}, -names(factors))
     vars %<>% select_numeric_cols()
